#! /bin/sh -
# This is a simple XML prettyprinter.  The default XML markup is the
# subset of DocBook/XML used in O'Reilly & Associates book production,
# but alternate markup can be defined in simple configuration files.
#
# Usage:
#	xmlfixup  [ --? ] \
#		  [ --configfile infile ] \
#		  [ --debug ] \
#		  [ --dumpconfig outfile] \
#		  [ --help ] \
#		  [ --indentation n ] \
#		  [ --level n ] \
#		  [ --version ] \
#		  [ --width n ] \
#		  [ -- ] \
#		  [ XML-file(s) ]
#
# Options may be prefixed with either one or two leading hyphens, and
# may be abbreviated to the minimum leading prefix (-d for --debug).

IFS='
 	'

PATH=/usr/local/bin:/bin:/usr/bin
export PATH

# This program requires gawk for RS-as-regular-expression and
# RT-as-record-terminator support.  Neither nawk nor mawk will do!
GAWK=${GAWK:-@GAWK@}

VERSION=1.01
DATE="[02-Dec-2003]"

program=$0
progbase=`basename $program`
libdir=`dirname $0`/../share/lib/$progbase/$progbase-$VERSION

usage()
{
    cat <<EOF
$progbase	[ --? ] [ --configfile infile ] [ --debug ]
		[ --dumpconfig outfile] [ --help ] [ --indentation n ]
		[ --level n ] [ --version ] [ --width n ] [ -- ]
		[ XML-file(s) ]
EOF
}

usage_and_exit()
{
    usage
    exit "$@"
}

version()
{
    echo "$program version $VERSION $DATE"
}

version_and_exit()
{
    version
    exit "$@"
}

args=

while test $# -gt 0
do
    case $1 in
    --configfile | --configfil | --configfi | --configf | --config | \
    --confi | --conf | --con | --co | --c | \
    -configfile | -configfil | -configfi | -configf | -config | \
    -confi | -conf | -con | -co | -c )
	shift
	args="$args -v ConfigFile=$1"
	;;

    --debug | --debu | --deb | --de | --d | \
    -debug | -debu | -deb | -de | -d )
	args="$args -v Debug=1"
	;;

    --dumpconfig | --dumpconfi | --dumpconf | --dumpcon | --dumpco | \
    --dumpc | --dump | --dum | --du | \
    -dumpconfig | -dumpconfi | -dumpconf | -dumpcon | -dumpco | \
    -dumpc | -dump | -dum | -du )
	shift
	args="$args -v DumpConfig=$1"
	;;

    '--?' | '-?' | \
    --help | --hel | --he | --h | \
    -help | -hel | -he | -h )
	usage_and_exit 0
	;;

    --indentation | --indentatio | --indentati | --indentat | --indenta | \
    --indent | --inden | --inde | --ind | --in | --i | \
    -indentation | -indentatio | -indentati | -indentat | -indenta | \
    -indent | -inden | -inde | -ind | -in | -i )
	shift
	args="$args -v Indent=$1"
	;;

    --level | --leve | --lev | --le | --l | \
    -level | -leve | -lev | -le | -l )
	shift
	args="$args -v Level=$1"
	;;

    --version | --versio | --versi | --vers | --ver | --ve | --v | \
    -version | -versio | -versi | -vers | -ver | -ve | -v )
	version_and_exit 0
	;;

    --width | --widt | --wid | --wi | --w | \
    -width | -widt | -wid | -wi | -w )
	shift
	args="$args -v Width=$1"
	;;

    --)
	break
	;;

    -*)
	echo "Unrecognized option: $1"
	usage_and_exit 1
	;;

    *)
	break
	;;

    esac
    shift
done

$GAWK -f $libdir/$progbase.awk $args -- "$@"
